==> currencyapi-1.0.0.tar.gz: currencyapi/src/Form/CurrencyApiSettingsForm.php <==
<?php

namespace Drupal\currencyapi\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class CurrencyApiSettingsForm extends ConfigFormBase {

  public function getFormId(): string {
    return 'currencyapi_settings';
  }

  protected function getEditableConfigNames(): array {
    return ['currencyapi.settings'];
  }

  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('currencyapi.settings');

    $form['api'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('API Configuration'),
    ];

    $form['api']['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $config->get('api_key'),
      '#required' => TRUE,
    ];

    $form['api']['api_url'] = [
      '#type' => 'url',
      '#title' => $this->t('API Endpoint'),
      '#default_value' => $config->get('api_url'),
      '#description' => $this->t('Base URL for the currency API service'),
    ];

    $form['currencies'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Currency Settings'),
    ];

    $form['currencies']['default_currencies'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Currencies'),
      '#default_value' => $config->get('default_currencies') ?? 'EUR,GBP,JPY,CAD',
      '#description' => $this->t('Comma-separated list of currency codes to display by default'),
    ];

    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('currencyapi.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('api_url', $form_state->getValue('api_url'))
      ->set('default_currencies', $form_state->getValue('default_currencies'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}

==> currencyapi-1.0.1.tar.gz: currencyapi/src/Form/CurrencyApiSettingsForm.php <==
<?php

namespace Drupal\currencyapi\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * A Configuration Form Class.
 */
class CurrencyApiSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'currencyapi_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['currencyapi.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('currencyapi.settings');

    $form['api'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('API Configuration'),
    ];

    $form['api']['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $config->get('api_key'),
      '#required' => TRUE,
    ];

    $form['api']['api_url'] = [
      '#type' => 'url',
      '#title' => $this->t('API Endpoint'),
      '#default_value' => $config->get('api_url'),
      '#description' => $this->t('Base URL for the currency API service'),
    ];

    $form['currencies'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Currency Settings'),
    ];

    $form['currencies']['currencies'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Currencies'),
      '#default_value' => $config->get('currencies') ?? 'EUR,GBP,JPY,CAD',
      '#description' => $this->t('Comma-separated list of currency codes sorted by your own preference'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('currencyapi.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('api_url', $form_state->getValue('api_url'))
      ->set('currencies', $form_state->getValue('currencies'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
